@@ -105,11 +105,12 @@ extern int getjoincount(struct channel *, char *);
 extern int delserver(char *, int, int, int, int, int);
 extern int setpassword(struct channel *, char *, char *);
 extern int logoff(struct channel *, char *);
-extern int logon(struct channel *, char *, char *, char *, int);
+extern int logon(struct channel *, struct botuser *, char *, char *, int);
 extern int timed_cmp(struct timed *, struct timed *);
 extern int isfriend(struct channel *, char *, char *);
 extern int deltachanflags(struct channel *, char *, char);
 extern int isvalidchannel(char *);
+extern int hasuserflags(struct channel *, char *, char *, char *);
 extern unsigned int getrandom(unsigned int);
 extern struct authed *addnewauthed(struct channel *, time_t, struct botuser *, char *);
 extern struct botuser *addbotuser(char *, char *);
@@ -140,7 +141,6 @@ extern struct chanuser *getrandomuser(struct channel *);
 extern struct timed *timed_new(struct channel *, time_t, int, int, char *);
 extern struct mmode *mmode_new(struct channel *, time_t, char *, char *);
 extern struct channel *clonechannel(char *, char *);
-extern struct botuser *hasuserflags(struct channel *, char *, char *);
 extern time_t lastoff(struct channel *, char *, char *);
 extern void sendadverts(struct channel *, char *, char *);
 extern void resetparts(struct channel *, char *, char *);
@@ -183,7 +183,7 @@ extern void syncuserhosts(void);
 extern void processenv(void);
 extern void processlock(struct channel *);
 extern void processnetjoin(struct channel *);
-extern void mmodes2timeds(struct channel *);
+extern void mmodes2timeds(void);
 extern void joinchannel(struct channel *);
 extern void updatelast(struct channel *, char *, char *, char *);
 extern void updateseen(struct channel *, char *, char *);
