@@ -499,7 +499,7 @@ void parseirc(char *serveroutput)
                         if(!gettobek(this, nick) && checkforbadnick(this, nick, userhost)) {
                                 changetobek(this, nick, 1);
                         }
-                        if(!gettobek(this, nick) && haschanflags(this, "v") && hasuserflags(this, userhost, "v") != NULL) {
+                        if(!gettobek(this, nick) && haschanflags(this, "v") && hasuserflags(this, userhost, "v", "")) {
 				mmode_new(this, mystate->now, "+v", nick);
                         }
                         if(!gettobek(this, nick) && haschanflags(this, "O") && isopa(userhost)) {
@@ -523,7 +523,7 @@ void parseirc(char *serveroutput)
                 if(!haschanflags(this, "q")) {
                         return;
                 }
-                if(hasuserflags(this, userhost, "x") != NULL) {
+                if(hasuserflags(this, userhost, "x", "")) {
                         return;
                 }
 		if((mystate->now - this->last_quote) < OER_QUOTE_INTERVAL) {
@@ -1003,7 +1003,7 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 #endif
 		return;
 	}
-	if(hasuserflags(this, userhost, "x") != NULL) {
+	if(hasuserflags(this, userhost, "x", "")) {
 		/* user's messages won't be saved */
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsemsg->messages from %s to %s won't be saved\n", nick, this->name);
@@ -1360,7 +1360,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		}
 		/* allow admins to use !rk and !rbk */
                 if(!isadmin(this, userhost)) {
-			if(hasuserflags(this, userhost, "or") == NULL) {
+			if(!hasuserflags(this, userhost, "or", "")) {
 				return;
 			}
 		}
@@ -1383,7 +1383,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		}
 		/* allow admins to use !rk and !rbk */
                 if(!isadmin(this, userhost)) {
-			if(hasuserflags(this, userhost, "or") == NULL) {
+			if(!hasuserflags(this, userhost, "or", "")) {
 				return;
 			}
 		}
@@ -1854,24 +1854,20 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->LOGOFF\n");
 #endif
-		if((this = getchptr(channel)) == NULL) {
-			return;
-		}
 		if(!strlen(restptr)) {
 			return;
 		}
+                this = getchptr(channel);
 		logoffcommand(this, (tochan) ? this->name : nick, tochan, nick, userhost, restptr);
 		return;
 	case OER_WHICHCOMMAND_LOGON:
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->LOGON\n");
 #endif
-		if((this = getchptr(channel)) == NULL) {
-			return;
-		}
 		if(!strlen(restptr)) {
 			return;
 		}
+                this = getchptr(channel);
 		logoncommand(this, (tochan) ? this->name : nick, tochan, nick, userhost, restptr);
 		return;
 	case OER_WHICHCOMMAND_ADD:
