@@ -327,6 +327,37 @@ if [ "$CREATECONF" = "y" ]; then
 	fi
 	
     done
+
+    KICKREASONS=`wc -l scripts/kickreasons.txt | awk '{print $1}'`
+    KICKREASONS=`expr $KICKREASONS + 1`
+    COUNTER=1
+
+    while [ $COUNTER -ne $KICKREASONS ]; do
+	REASON=`head -$COUNTER scripts/kickreasons.txt | tail -1`
+	REASON2=`echo $REASON | sed "s/'/''/"`
+        NREASON="INSERT INTO kickreasons VALUES ('$REASON2', '$HANDLE')"
+	if [ "$DBUSERPW" = "" ]; then
+	    LOGTHIS=`( $ECHO "$NREASON" | $1/mysql -h $HOST -u $DBUSER $DB ) 2>&1`
+	    RC=$?
+	    $ECHO $LOGTHIS >> $LOGTO
+	else
+	    LOGTHIS=`( $ECHO "$NREASON" | $1/mysql -h $HOST -u $DBUSER -p$DBUSERPW $DB ) 2>&1`
+	    RC=$?
+	    $ECHO $LOGTHIS >> $LOGTO
+	fi
+
+	if [ $RC -eq 1 ]; then
+	    $ECHO "failed"
+	    $ECHO ""
+	    $ECHO "Check that the settings haven't already been stored into the database"
+	    $ECHO "If they have, either delete them or skip this phase"
+	    $ECHO ""
+	    exit 1
+	fi
+
+	COUNTER=`expr $COUNTER + 1`
+    done
+
     $ECHO "ok"
 fi
 
